@@ -230,9 +230,9 @@ const QPixmap IconWidget::loadSvg(const QString &fileName, const QSize &size) co
 {
     const auto ratio = devicePixelRatioF();
 
-    QPixmap pixmap;
-    pixmap = QIcon::fromTheme(fileName, m_icon).pixmap(size * ratio);
-    pixmap.setDevicePixelRatio(ratio);
+    auto pixmapSize = QCoreApplication::testAttribute(Qt::AA_UseHighDpiPixmaps) ? size : (size * ratio);
+
+    QPixmap pixmap = QIcon::fromTheme(fileName, m_icon).pixmap(pixmapSize);
 
     return pixmap;
 }
