@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
- *
- * Author:     Hou Lei <houlei@uniontech.com>
- *
- * Maintainer: Liu Zheng <liuzheng@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "configsettings.h"
 #include "saveutils.h"
@@ -103,20 +87,22 @@ QVariant ConfigSettings::getDefaultValue(const QString &group, const QString &ke
     QVariant value;
     // QVariant 初始化默认值
     // toInt() == 0, toString() == "", toBool() == false
-    if(Utils::isTabletEnvironment && group == "recordConfig") {
+    if (Utils::isTabletEnvironment && group == "recordConfig") {
         // 平板默认录屏参数，MP4,24帧
-        if(key == "save_as_gif") {
+        if (key == "save_as_gif") {
             return QVariant(false);
-        } else if(key == "lossless_recording") {
+        } else if (key == "lossless_recording") {
             return QVariant(false);
         } else if (key == "mkv_framerate") {
             return QVariant(24);
         }
     }
-
-    if(key == "fontsize"){
+    if (key == "save_op_record") {
+        value.setValue(SaveAction::SaveToVideo);
+    }
+    if (key == "fontsize") {
         value.setValue(12);
-    }else if (key == "saveClip") {
+    } else if (key == "saveClip") {
         value.setValue(1);
     } else if (key == "save_op") {
         if (Utils::isTabletEnvironment) {
