@@ -20,14 +20,14 @@ o haga clic en el icono de la bandeja</translation>
     </message>
     <message>
         <source>Recording</source>
-        <translation type="unfinished"/>
+        <translation>Grabaciones</translation>
     </message>
 </context>
 <context>
     <name>MainToolWidget</name>
     <message>
         <source>Record</source>
-        <translation>Grabar</translation>
+        <translation>Grabación</translation>
     </message>
     <message>
         <source>Screenshot</source>
@@ -96,10 +96,6 @@ o haga clic en el icono de la bandeja</translation>
         <source>Screenshot</source>
         <translation>Captura de pantalla</translation>
     </message>
-    <message>
-        <source>The screenshot has been saved in the album</source>
-        <translation>La captura de pantalla se ha guardado en el álbum.</translation>
-    </message>
     <message>
         <source>Screenshot failed.</source>
         <translation>Captura de pantalla fallida</translation>
@@ -112,6 +108,10 @@ o haga clic en el icono de la bandeja</translation>
         <source>Pin Screenshots</source>
         <translation>Anclar captura de pantalla</translation>
     </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>Abrir carpeta</translation>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -153,6 +153,10 @@ o haga clic en el icono de la bandeja</translation>
         <source>Record</source>
         <translation>Grabación</translation>
     </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>Abrir carpeta</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -357,6 +361,14 @@ o haga clic en el icono de la bandeja</translation>
         <source>Pin screenshots</source>
         <translation>Anclar captura de pantalla</translation>
     </message>
+    <message>
+        <source>Start OCR</source>
+        <translation>Iniciar OCR</translation>
+    </message>
+    <message>
+        <source>Start scrollshot</source>
+        <translation>Iniciar captura de desplazamiento</translation>
+    </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
@@ -548,11 +560,15 @@ o haga clic en el icono de la bandeja</translation>
     </message>
     <message>
         <source>webm</source>
-        <translation type="unfinished"/>
+        <translation>webm</translation>
     </message>
     <message>
         <source>ogg</source>
-        <translation type="unfinished"/>
+        <translation>ogg</translation>
+    </message>
+    <message>
+        <source>Videos</source>
+        <translation>Videos</translation>
     </message>
 </context>
 <context>
