@@ -96,10 +96,6 @@ clique no ícone da bandeja ou use o atalho</translation>
         <source>Screenshot</source>
         <translation>Capturar</translation>
     </message>
-    <message>
-        <source>The screenshot has been saved in the album</source>
-        <translation>A captura de tela foi salva no álbum</translation>
-    </message>
     <message>
         <source>Screenshot failed.</source>
         <translation>A captura de tela falhou.</translation>
@@ -112,6 +108,10 @@ clique no ícone da bandeja ou use o atalho</translation>
         <source>Pin Screenshots</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Open Folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -153,6 +153,10 @@ clique no ícone da bandeja ou use o atalho</translation>
         <source>Record</source>
         <translation>Gravar</translation>
     </message>
+    <message>
+        <source>Open Folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -357,6 +361,14 @@ clique no ícone da bandeja ou use o atalho</translation>
         <source>Pin screenshots</source>
         <translation>Fixar capturas de tela</translation>
     </message>
+    <message>
+        <source>Start OCR</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Start scrollshot</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
@@ -554,6 +566,10 @@ clique no ícone da bandeja ou use o atalho</translation>
         <source>ogg</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Videos</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
