@@ -95,10 +95,6 @@ or press the shortcut again to stop recording</source>
         <source>Screenshot</source>
         <translation>رەسىم تۇتۇش</translation>
     </message>
-    <message>
-        <source>The screenshot has been saved in the album</source>
-        <translation>ئېكران كەسمە سۈرىتى ئالبۇمغا ساقلاندى</translation>
-    </message>
     <message>
         <source>Screenshot failed.</source>
         <translation>رەسىم تۇتۇلمىدى</translation>
@@ -111,6 +107,10 @@ or press the shortcut again to stop recording</source>
         <source>Pin Screenshots</source>
         <translation>چاپلاق</translation>
     </message>
+    <message>
+        <source>Open Folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -152,6 +152,10 @@ or press the shortcut again to stop recording</source>
         <source>Record</source>
         <translation>سىنغا ئېلىش</translation>
     </message>
+    <message>
+        <source>Open Folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -356,6 +360,14 @@ or press the shortcut again to stop recording</source>
         <source>Pin screenshots</source>
         <translation>چاپلاق</translation>
     </message>
+    <message>
+        <source>Start OCR</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Start scrollshot</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
@@ -553,6 +565,10 @@ or press the shortcut again to stop recording</source>
         <source>ogg</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Videos</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
