@@ -20,7 +20,7 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>Recording</source>
-        <translation type="unfinished"/>
+        <translation>Записування</translation>
     </message>
 </context>
 <context>
@@ -96,10 +96,6 @@ or press the shortcut again to stop recording</source>
         <source>Screenshot</source>
         <translation>Знімок</translation>
     </message>
-    <message>
-        <source>The screenshot has been saved in the album</source>
-        <translation>Знімок вікна було збережено до альбому</translation>
-    </message>
     <message>
         <source>Screenshot failed.</source>
         <translation>Не вдалося створити знімок.</translation>
@@ -112,6 +108,10 @@ or press the shortcut again to stop recording</source>
         <source>Pin Screenshots</source>
         <translation>Пришпилити знімки</translation>
     </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>Відкрити теку</translation>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -153,6 +153,10 @@ or press the shortcut again to stop recording</source>
         <source>Record</source>
         <translation>Записати</translation>
     </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>Відкрити теку</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -357,6 +361,14 @@ or press the shortcut again to stop recording</source>
         <source>Pin screenshots</source>
         <translation>Пришпилити знімки</translation>
     </message>
+    <message>
+        <source>Start OCR</source>
+        <translation>Почати розпізнавання</translation>
+    </message>
+    <message>
+        <source>Start scrollshot</source>
+        <translation>Почати знімок із гортанням</translation>
+    </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
@@ -554,6 +566,10 @@ or press the shortcut again to stop recording</source>
         <source>ogg</source>
         <translation>ogg</translation>
     </message>
+    <message>
+        <source>Videos</source>
+        <translation>Відео</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
